@@ -2,12 +2,8 @@
 "_PACKAGE"
 
 ## usethis namespace: start
-#' @importFrom cli cli_abort
 #' @importFrom rlang check_dots_empty0
 #' @importFrom stats ave
 #' @importFrom tibble new_tibble
 ## usethis namespace: end
 NULL
-
-#' @useDynLib ageutils, .registration = TRUE, .fixes = "C_"
-NULL
